@@ -30,7 +30,12 @@
 # Standard python modules
 #
 #------------------------------------------------------------------------
-import os,string,tempfile,socket,datetime
+import os
+import tempfile
+import socket
+import datetime
+import time
+import apt
 
 #------------------------------------------------------------------------
 #
@@ -58,17 +63,18 @@ import perform
 #
 #------------------------------------------------------------------------
 init_dir = os.path.expanduser("~/.wajig/") + socket.gethostname()
-if not os.path.exists(init_dir): os.makedirs(init_dir)
+if not os.path.exists(init_dir):
+    os.makedirs(init_dir)
 #
 # Temporarily, remove old files from .wajig
 # After a few versions remove this code.
 #
 tmp_dir = os.path.expanduser("~/.wajig")
-if os.path.exists(tmp_dir + "/Available"): 
+if os.path.exists(tmp_dir + "/Available"):
     os.rename(tmp_dir + "/Available", init_dir + "/Available")
-if os.path.exists(tmp_dir + "/Available.prv"): 
+if os.path.exists(tmp_dir + "/Available.prv"):
     os.rename(tmp_dir + "/Available.prv", init_dir + "/Available.prv")
-if os.path.exists(tmp_dir + "/Installed"): 
+if os.path.exists(tmp_dir + "/Installed"):
     os.rename(tmp_dir + "/Installed", init_dir + "/Installed")
 
 # 100104 Remove any old tmp files. Bug#563573
@@ -101,7 +107,7 @@ log_file       = init_dir + "/Log"
 #
 # No longer using the Installed file so remove it. 23 Aug 2003
 #
-if os.path.exists(init_dir + "/Installed"): 
+if os.path.exists(init_dir + "/Installed"):
     os.remove(init_dir + "/Installed")
 #
 # Packages cache
@@ -125,29 +131,19 @@ if os.path.exists(init_dir + "/Packages"):
     os.remove(init_dir + "/Packages")
 
 #
-# Set the temporary directory to the init_dir.  
+# Set the temporary directory to the init_dir.
 # Large files are not generally written there so should be okay.
 #
 tempfile.tempdir = init_dir
 
+
 def get_available_filename():
-    """Obtain the name of the file containing list of available packages.
-
-    Arguments:
-
-    Returns:
-    string      The filename"""
-
+    "Obtain the name of the file containing list of available packages."
     return available_file
 
+
 def get_previous_filename():
-    """Obtain the name of the file containing list of previous packages.
-
-    Arguments:
-
-    Returns:
-    string      The filename"""
-
+    "Obtain the name of the file containing list of previous packages."
     return previous_file
 
 #------------------------------------------------------------------------
@@ -158,13 +154,11 @@ def get_previous_filename():
 def update_available(noreport=False):
     """Generate current list of available packages, backing up the old list.
 
-    Arguments:
-    noreport    If set then do not report on the number of packages.
-
-    Returns:"""
+    noreport    If set, do not report on the number of packages.
+    """
 
     if not os.path.exists(available_file):
-        f = open(available_file,"w")
+        f = open(available_file, "w")
         f.close()
 
     temporary_file = tempfile.mktemp()
@@ -176,7 +170,7 @@ def update_available(noreport=False):
               "| perl -p -e 's|Package: |\n|g; s|Version: ||g'" +\
               "| sort -k 1b,1 | tail -n +2 | sed 's| $||' > " + available_file
     # Use langC in the following since it uses a grep.
-    perform.execute(command, noquiet=True, langC=True) # root is not required.
+    perform.execute(command, noquiet=True, langC=True)  # root is not required.
     os.rename(temporary_file, previous_file)
 
     available_packages = len(open(available_file).readlines())
@@ -189,7 +183,7 @@ def update_available(noreport=False):
                              " | wc -l", pipe=True, langC=True).readlines()[0].strip()
     if not noreport:
         if diff < 0:
-            direction = str(0-diff) + " down on"
+            direction = str(0 - diff) + " down on"
         elif diff == 0:
             direction = "the same as"
         else:
@@ -211,31 +205,40 @@ def update_available(noreport=False):
 # finished. This will write a summary of changes to the log file.
 #
 old_log = tempfile.mktemp()
+
 def start_log():
     # Write list of installed to tmp file
     perform.execute(gen_installed_command_str() + " > " + old_log,
-                    noquiet=1, langC=True)
+                    noquiet=True, langC=True)
+
 
 def finish_log():
     ts = datetime.datetime.today().isoformat()
-    ts = ts[:-10] # Don't put seconds - it implies too much accuracy
+    ts = ts[:-10]  # Don't put seconds - it implies too much accuracy
     # Generate new list of installed and compare to old
     lf = file(log_file, "a")
     new_iter = perform.execute(gen_installed_command_str(),
-                               noquiet=1, langC=True, pipe=True)
+                               noquiet=True, langC=True, pipe=True)
     old_iter = file(old_log)
     for o in old_iter:
         o = o.strip().split(" ")
         n = new_iter.next().strip().split(" ")
-        while o[0] <> n[0]:
+        while o[0] != n[0]:
             if o[0] < n[0]:
                 lf.write("%s %s %s %s\n" % (ts, "remove", o[0], o[1]))
                 o = old_iter.next().strip().split(" ")
             elif o[0] > n[0]:
                 lf.write("%s %s %s %s\n" % (ts, "install", n[0], n[1]))
                 n = new_iter.next().strip().split(" ")
-        if o[1] <> n[1]:
-            lf.write("%s %s %s %s\n" % (ts, "upgrade", n[0], n[1]))
+
+        if o[1] != n[1]:
+            old_version = o[1].split(".")  # for a more accurate comparison
+            new_version = n[1].split(".")  # same
+            if old_version > new_version:
+                lf.write("{0} {1} {2} {3}\n".format(ts, "downgrade", n[0], n[1]))
+            else:
+                lf.write("{0} {1} {2} {3}\n".format(ts, "upgrade", n[0], n[1]))
+
     os.remove(old_log)
 
 #------------------------------------------------------------------------
@@ -244,51 +247,52 @@ def finish_log():
 #
 #------------------------------------------------------------------------
 def gen_installed_command_str():
-    """Generate command to list installed packages and their status."""
+    "Generate command to list installed packages and their status."
     command = "cat /var/lib/dpkg/status | " +\
               "egrep '^(Package|Status|Version):' | " +\
               "awk '/^Package: / {pkg=$2} " +\
               "     /^Status: / {s1=$2;s2=$3;s3=$4}" +\
               "     /^Version: / {print pkg,$2,s1,s2,s3}' | " +\
               "grep 'ok installed' | awk '{print $1,$2}' | sort -k 1b,1"
-    return(command)
+    return command
+
 
 def count_upgrades():
-    """Return as a string the number of new upgrades since last update."""
+    "Return as a string the number of new upgrades since last update."
     ifile = tempfile.mktemp()
     # Use langC in the following since it uses a grep.
     perform.execute(gen_installed_command_str() + " > " + ifile,
-                    langC=True, noquiet=1)
+                    langC=True, noquiet=True)
     command = "join " + previous_file + " " + available_file + " |" +\
               "awk '$2 != $3 {print}' | sort -k 1b,1 | join - " + ifile + " |" +\
               "awk '$4 != $3 {print}' | wc -l | awk '{print $1}' "
     # 090425 Use langC=True to work with change from coreutils 6.10 to 7.2
-    count = string.split(perform.execute(command, noquiet=1, pipe=1, langC=True).read())[0]
-    if os.path.exists(ifile): os.remove(ifile)
+    count = perform.execute(command, noquiet=True, pipe=True,
+            langC=True).read().split()[0]
+    if os.path.exists(ifile):
+        os.remove(ifile)
     return count
 
-def reset_files():    
-    if os.path.exists(available_file): os.remove(available_file)
-    if os.path.exists(previous_file): os.remove(previous_file)
-    update_available(noreport=1)
-    update_available(noreport=1)
+
+def reset_files():
+    if os.path.exists(available_file):
+        os.remove(available_file)
+    if os.path.exists(previous_file):
+        os.remove(previous_file)
+    update_available(noreport=True)
 
 #------------------------------------------------------------------------
 #
-# ENSURE INITIALISED 
+# ENSURE INITIALISED
 #
 #------------------------------------------------------------------------
-def ensure_initialised(): 
-    """Make sure the init_dir and files exist and if not, create them.
-
-    Arguments:
-
-    Returns:"""
-
-    if not os.path.exists(available_file): reset_files()
+def ensure_initialised():
+    "Create the init_dir and files if they don't exist."
+    if not os.path.exists(available_file):
+        reset_files()
 
 #------------------------------------------------------------------------
-# 
+#
 # Dictionaries of available, installed, and previously available packages.
 #
 #------------------------------------------------------------------------
@@ -296,136 +300,106 @@ available_list = {}
 previous_list = {}
 installed_list = {}
 
+
 def load_dictionaries():
-    """Create dictionaries of avail/installed packages for in-memory tasks."""
+    "Create dictionaries of avail/installed packages for in-memory tasks."
 
     ensure_initialised()
-    
-    afile = open(available_file,"r").readlines()
-    for i in range(0,len(afile)):
-        available_list[string.split(afile[i])[0]] = string.split(afile[i])[1]
 
-    pfile = open(previous_file,"r").readlines()
-    for i in range(0,len(pfile)):
-        previous_list[string.split(pfile[i])[0]] = string.split(pfile[i])[1]
+    afile = open(available_file, "r").readlines()
+    for i in range(0, len(afile)):
+        available_list[afile[i].split()[0]] = afile[i].split()[1]
+
+    pfile = open(previous_file, "r").readlines()
+    for i in range(0, len(pfile)):
+        previous_list[pfile[i].split()[0]] = pfile[i].split()[1]
 
     ifile = perform.execute(gen_installed_command_str(),
-                            noquiet=1, pipe=1).readlines()
-    for i in range(0,len(ifile)):
-        installed_list[string.split(ifile[i])[0]] = string.split(ifile[i])[1]
+                            noquiet=True, pipe=True).readlines()
+    for i in range(0, len(ifile)):
+        installed_list[ifile[i].split()[0]] = ifile[i].split()[1]
+
 
 def get_available_list():
-    """Obtain the dictionary of available packages.
-
-    Arguments:
-
-    Returns:
-    dictionary  Available packages"""
-
+    "Obtain the dictionary of available packages."
     return available_list
 
+
 def get_previous_list():
-    """Obtain the dictionary of previously available packages.
-
-    Arguments:
-
-    Returns:
-    dictionary  Previously available packages"""
-
+    "Obtain the dictionary of previously available packages."
     return previous_list
 
+
 def get_available_version(pkg):
-    """Obtain the package's available version number.
-
-    Arguments:
-
-    Returns:
-    string      available version"""
-
+    "Obtain the package's available version number."
     return available_list[pkg]
 
+
 def get_previous_version(pkg):
-    """Obtain the package's previously available version number.
-
-    Arguments:
-
-    Returns:
-    string      Previous version"""
-
+    "Obtain the package's previously available version number."
     return previous_list[pkg]
 
+
 def get_installed_version(pkg):
-    """Return, as string, the package's installed version number."""
+    "Return, as string, the package's installed version number."
     # TODO: Make sure the dictionary has been loaded.
     return installed_list[pkg]
 
+
 def get_new_available():
-    """Obtain the packages available now but not previously.
-
-    Arguments:
-
-    Returns:
-    list        New packages"""
+    "Obtain the packages available now but not previously."
     load_dictionaries()
     new_list = []
     for pkg in available_list.keys():
-        if not previous_list.has_key(pkg):
+        if not pkg in previous_list:
             new_list.append(pkg)
     return new_list
 
+
 def get_new_upgrades():
-    """Obtain the packages upgraded since previously.
-
-    Arguments:
-
-    Returns:
-    list        Newly upgraded packages"""
+    "Obtain newly-upgraded packages"
     load_dictionaries()
     upgraded_list = []
-    apt_pkg.init_system(); # Not sure why!
+    apt_pkg.init_system()  # Not sure why!
     for pkg in installed_list.keys():
-        if available_list.has_key(pkg) \
-           and previous_list.has_key(pkg) \
-           and apt_pkg.version_compare(available_list[pkg],
-                                      previous_list[pkg]) > 0:
+        if pkg in available_list and pkg in previous_list \
+        and apt_pkg.version_compare(available_list[pkg],
+        previous_list[pkg]) > 0:
             upgraded_list.append(pkg)
     return upgraded_list
 
+
 def get_to_upgrade():
-    """Obtain the packages with newer versions available.
-
-    Arguments:
-
-    Returns:
-    list        Upgradeable packages"""
-
+    "Obtain the packages with newer versions available."
     load_dictionaries()
     upgraded_list = []
-    apt_pkg.init_system(); # Not sure why!
+    apt_pkg.init_system()  # Not sure why!
     for pkg in installed_list.keys():
-        if available_list.has_key(pkg) \
-           and apt_pkg.version_compare(available_list[pkg],
-                                      installed_list[pkg]) > 0:
+        if pkg in available_list \
+        and apt_pkg.version_compare(available_list[pkg],
+        installed_list[pkg]) > 0:
             upgraded_list.append(pkg)
     return upgraded_list
 
+
 def get_status(pkg):
     p = perform.execute("dpkg --status " + pkg, pipe=True)
     pkginfo = apt_pkg.TagFile(p)
     return pkginfo.next().get("Status")
 
+
 def get_dependees(pkg):
-    """Return a list of other installed pkgs that depend on PKG."""
+    "Return a list of other installed pkgs that depend on PKG."
     pkginfo = perform.execute("apt-cache rdepends --installed " +
                               pkg, pipe=True)
     dp = []
     # Watch for changes to apt-cache output.
-    if pkginfo.next().strip() <> pkg:
+    if pkginfo.next().strip() != pkg:
         print "wajig: unexpected result from apt-cache - submit a bug report"
-    if pkginfo.next().strip() <> "Reverse Depends:":
+    if pkginfo.next().strip() != "Reverse Depends:":
         print "wajig: unexpected result from apt-cache - submit a bug report"
     for l in pkginfo:
-        pn = l.strip().split(',')[0].replace('|','')
+        pn = l.strip().split(',')[0].replace('|', '')
         dp.append(pn)
     #
     # If dp is too long, don't check install status.
@@ -441,16 +415,42 @@ def get_dependees(pkg):
                 np.append(p)
     return np
 
+
 def get_dependencies(pkg):
-    """Return a list of installed packages that PKG depends on."""
+    "Return a list of installed packages that PKG depends on."
     pkginfo = perform.execute("apt-cache depends --installed " +
                               pkg, pipe=True)
     dp = []
     # Watch for changes to apt-cache output.
-    if pkginfo.next().strip() <> pkg:
+    if pkginfo.next().strip() != pkg:
         print "wajig: unexpected result from apt-cache - submit a bug report"
     # Find package names. Ignore "<name>" as these are not installed.
     for l in pkginfo:
         if l.find(":") >= 0 and l.find("<") < 0:
             dp.append(l.split()[1])
     return dp
+
+
+def backup_before_upgrade(bkdir):
+    perform.execute("apt-get update", root=True)
+    cache = apt.Cache()
+    cache.upgrade()
+    pkgs = [pkg.name for pkg in cache.get_changes()]
+    if pkgs:
+        date = time.strftime("%Y-%m-%d_%H:%M:%S", time.localtime())
+        if bkdir:
+            target = os.path.abspath(bkdir + "/" + date)
+            try:
+                os.makedirs(target)
+            except Exception, e:
+                print "Quitting:", e
+        else:
+            target = init_dir + "/backups/" + date
+            os.makedirs(target)
+        os.chdir(target)
+        print "The packages will saved in", target
+        for pkg in pkgs:
+            command = "fakeroot -u dpkg-repack " + pkg
+            perform.execute(command)
+    else:
+        print "No upgrades."
