@@ -23,14 +23,18 @@
 #
 # Standard python modules
 #
-import os,re,string,sys,tempfile,signal,datetime
+import os
+import re
+import sys
+import tempfile
+import signal
 #
 # When writing to a pipe where there is no reader (e.g., when
 # output is directed to head or to less and the user exists from less
 # before reading all output) the SIGPIPE signal is generated. Capture
 # the signal and hadle it with the default handler.
 #
-signal.signal(signal.SIGPIPE,signal.SIG_DFL)
+signal.signal(signal.SIGPIPE, signal.SIG_DFL)
 
 #
 # APT module
@@ -55,10 +59,12 @@ previous_file  = changes.get_previous_filename()
 #
 verbose = 0
 
+
 def set_verbosity_level(new_level):
     global verbose
     verbose = new_level
 
+
 def commify(strnum):
     strnum = str(strnum)
     if len(strnum) <= 3:
@@ -76,29 +82,30 @@ def ping_host(hostname):
     # Check if fping is installed.
     #
     if perform.execute("fping localhost 2>/dev/null >/dev/null",
-                       display=0) != 0:
+                       display=False) != 0:
         print "JIG Warning: fping was not found. " +\
               "Consider installing the package fping.\n"
     #
     # Check if we can talk to the HOST
     #
     elif perform.execute("fping " + hostname + " 2>/dev/null >/dev/null",
-                         display=0) != 0:
+                         display=False) != 0:
         print "JIG Warning: Could not contact the Debian server at\n" +\
               "             " + hostname + """
              Perhaps it is down or you are not connected to the network.
              JIG will continue to try to get the information required.
 """
 
+
 def get_available(command="dumpavail"):
     "Return an apt_pkg object that represents the parsed list of packages."
-    
+
     # This originally ran the apt-cache command as a pipe to
     # TagFile as in:
     #  command = "apt-cache dumpavail"
     #  packages_pipe = perform.execute(command, noquiet=True, pipe=True)
     #  avail = apt_pkg.TagFile(packages_pipe)
-    #    
+    #
     # But as in Bug#366678 TagFile no longer works in a pipe
     # because of changes to apt_pkg by Michael Vogt. He supplied
     # suggested fixes, but they were not tested and I've not had
@@ -118,15 +125,16 @@ def get_available(command="dumpavail"):
     perform.execute(command)
     # 090501 End
     avail = apt_pkg.TagFile(file(tmpcache))
-    if os.path.exists(tmpcache): os.remove(tmpcache)
-    return(avail)
+    if os.path.exists(tmpcache):
+        os.remove(tmpcache)
+    return avail
 
 def do_dependents(package):
     command = "apt-cache showpkg " + package +\
               " | awk \'BEGIN{found=0}/^Reverse Depends:/{found=1;next}/^[^ ]/{found=0}found==1{print}{next}\' " +\
               " | sed \'s|Reverse Depends:||\' | tr \",\" \" \" " +\
               " | awk \'{print $1}\' | sort -u -k 1b,1 | grep -v \'^$\'"
-    packages = perform.execute(command, pipe = True)
+    packages = perform.execute(command, pipe=True)
     pkgs = []
     for pkg in packages:
         pkgs.append(pkg.strip())
@@ -148,17 +156,17 @@ def do_dependents(package):
             if not con: con = ""
             if not rep: rep = ""
             if package in dep:
-                print "d", nam # depends
+                print "d", nam  # depends
             elif package in sug:
-                print "s", nam # suggests
+                print "s", nam  # suggests
             elif package in rec:
-                print "r", nam # recommends
+                print "r", nam  # recommends
             elif package in con:
-                print "c", nam # conflicts
+                print "c", nam  # conflicts
             elif package in rep:
-                print "p", nam # replaces
+                print "p", nam  # replaces
             else:
-                print "o", nam # other
+                print "o", nam  # other
 
 #------------------------------------------------------------------------
 #
@@ -195,7 +203,7 @@ def do_describe(packages):
     # I did think to move to /var/cache/apt/available so I don't need to
     # use dpkg's copy which is not updated by apt-get update.
     # Hoever, "dselect update" does update it after doing
-    # "apt-get update". 
+    # "apt-get update".
     #
     # So it seems "apt-get update" updates /var/cache/apt/pkgcache.bin not
     # /var/cache/apt/available.  Thus new packages are not found in available.
@@ -264,7 +272,7 @@ def do_describe(packages):
         if (section.get("Package") in packages):
             package_name = section.get("Package")
             package_description = section.get("Description")
-            if not describe_list.has_key(package_name):
+            if not package_name in describe_list:
                 describe_list[package_name] = package_description
     # Bug fix for Bug#366678 Part 2 - not working yet???
     # mvo: its probably a good idea to keep the cache around in all of wajig
@@ -306,38 +314,38 @@ def do_describe(packages):
 #                       "| head -1 | cut -d' ' -f2- "
 #        command += ") | sort"
 #        perform.execute(command)
-        
+
         # TODO mvo suggests apt.Package.summary may be helpful here
         for pkg in pkgs:
             # Only print that first line, but check that there
             # is a description available.
             package_short_description = ""
             if describe_list[pkg]:
-              line_end = string.find(describe_list[pkg],"\n")
-              package_short_description = describe_list[pkg][0:line_end]
-            print "%-24s %s" % (pkg, string.capitalize(package_short_description))
+                line_end = describe_list[pkg].find("\n")
+                package_short_description = describe_list[pkg][0:line_end]
+            print "%-24s %s" % (pkg, package_short_description.capitalize())
     elif verbose == 1:
         for pkg in pkgs:
-            print pkg + ": " + string.capitalize(describe_list[pkg]) + "\n"
+            print pkg + ": " + describe_list[pkg].capitalize() + "\n"
     else:
         #
         # TODO is there a way of doing this using apt_pkg easily?
         # Otherwise "apt-cache show" seems okay if a little slower.
         #
-# Comment out for fix for Bug#366678 
+# Comment out for fix for Bug#366678
         package_names = perform.concat(packages)
         command = "apt-cache show " + package_names
         perform.execute(command)
 # Bug#366678 fix from mvo - part 3 - not working yet???
-#         for pkgname in filter(lambda pkgname: cache.has_key(pkgname), packages):
-#             pkg = cache[pkgname]
-#             for ver in pkg._pkg.VersionList:
-#                 if ver == None or ver.FileList == None:
-#                     print "no ver or ver.FileList"
-#                     continue
-#                 f, index = ver.FileList.pop(0)
-#                 cache._records.Lookup((f,index))
-#                 print cache._records.Record
+#   for pkgname in filter(lambda pkgname: cache.has_key(pkgname), packages):
+#       pkg = cache[pkgname]
+#       for ver in pkg._pkg.VersionList:
+#           if ver == None or ver.FileList == None:
+#              print "no ver or ver.FileList"
+#               continue
+#           f, index = ver.FileList.pop(0)
+#           cache._records.Lookup((f,index))
+#           print cache._records.Record
 
 #------------------------------------------------------------------------
 #
@@ -354,11 +362,11 @@ def do_describe_new(install=False):
     #
     # Describe each new package.
     #
-    new_pkgs = changes.get_new_available();
+    new_pkgs = changes.get_new_available()
     if len(new_pkgs) == 0:
         print "No new packages"
     else:
-        do_describe(new_pkgs);
+        do_describe(new_pkgs)
         if install:
             print "="*76
             do_install(new_pkgs)
@@ -424,7 +432,7 @@ def do_force(packages):
             # Identify the latest version of the package available in
             # the download archive, if there is any there.
             #
-            lscmd  = "/bin/ls " + archives
+            lscmd = "/bin/ls " + archives
             lscmd += " | egrep '^" + pkg + "_' | sort -k 1b,1 | tail -n -1"
             matches = perform.execute(lscmd, pipe=True)
             debpkg = matches.readline().strip()
@@ -433,7 +441,7 @@ def do_force(packages):
             # it is force installed.
             #
             if not debpkg:
-                dlcmd  = "apt-get --quiet=2 --reinstall --download-only "
+                dlcmd = "apt-get --quiet=2 --reinstall --download-only "
                 dlcmd += "install '" + pkg + "'"
                 perform.execute(dlcmd, root=1)
                 matches = perform.execute(lscmd, pipe=True)
@@ -468,7 +476,6 @@ def do_hold(packages):
     print "The following packages are on hold:"
     perform.execute("dpkg --get-selections | egrep 'hold$' | cut -f1")
 
-    
 
 #------------------------------------------------------------------------
 #
@@ -502,13 +509,16 @@ def do_install(packages, noauth=""):
     # If reading from standard input generate the list of packages.
     #
     if len(packages) == 1 and packages[0] == "-":
-        packages = string.split(
-            string.join(map(string.strip,sys.stdin.readlines())))
+        stripped = [x.strip() for x in sys.stdin.readlines()]
+        joined = str.join(stripped)
+        packages = joined.split()
     #
     # If reading packages from file generate list of packages.
     #
     elif len(packages) == 2 and packages[0] == "-f":
-        packages = string.split(string.join(map(string.strip,(open(packages[1])).readlines())))
+        stripped = [x.strip() for x in open(packages[1]).readlines()]
+        joined = str.join(stripped)
+        packages = str.split(joined)
     #
     # Check if a specific web location was specified.
     #
@@ -522,28 +532,29 @@ def do_install(packages, noauth=""):
         if not perform.execute(command):
             command = "dpkg --install " + tmpdeb
             perform.execute(command, root=1)
-            if os.path.exists(tmpdeb): os.remove(tmpdeb)
+            if os.path.exists(tmpdeb):
+                os.remove(tmpdeb)
         else:
             print "Wajig: The location " + packages[0] +\
                   " was not found. Check and try again."
-            return()
+            return
     #
     # Check if a specific .DEB file was specified
     #
     elif re.match(".*\.deb$", packages[0]):
-        command = "dpkg -i "
+        command = "dpkg -i"
         for pkg in packages:
             if os.path.exists(pkg):
-                command = command + "'" + pkg + "' "
+                command = "{0} '{1}' ".format(command, pkg)
             elif os.path.exists("/var/cache/apt/archives/" + pkg):
-                command = command + "'/var/cache/apt/archives/" + pkg + "' "
+                command = "{0} '/var/cache/apt/archives/{1}' ".format(command, pkg)
             else:
                 print "Wajig: The file " + pkg +\
                       " not found in either the" +\
                       " current directory\n" +\
                       "       nor in /var/cache/apt/archives/\n" +\
                       "       Please confirm location and try again."
-                return()
+                return
         perform.execute(command, root=1)
     #
     # Check if a "/+" is in a package name then use the following distribution
@@ -577,7 +588,7 @@ def do_install_suggest(packages, type, noauth=""):
     """Install packages suggested by the listed packages.
 
     Arguments:
-    packages    List of packages 
+    packages    List of packages
     noauth      A string which might be --allow-unathenticated
 
     Returns:"""
@@ -586,14 +597,15 @@ def do_install_suggest(packages, type, noauth=""):
     # If reading from stanard input generate the list of packages
     #
     if len(packages) == 1 and packages[0] == "-":
-        packages = string.split(
-            string.join(map(string.strip,sys.stdin.readlines())))
-        
+        stripped = [x.strip() for x in sys.stdin.readlines()]
+        joined = str.join(stripped)
+        packages = joined.split()
+
     #
     # For each package obtain the list of suggested packages
     #
     suggest_list = ""
-    
+
     ## Obtain the details of each available package.
 
     avail = get_available()
@@ -605,9 +617,11 @@ def do_install_suggest(packages, type, noauth=""):
             sug = section.get("Suggests")
             rec = section.get("Recommends")
             if type == "Suggests" or type == "Both":
-                if sug: suggest_list = suggest_list+" "+sug
+                if sug:
+                    suggest_list = suggest_list+" "+sug
             if type == "Recommends" or type == "Both":
-                if rec: suggest_list = suggest_list+" "+rec
+                if rec:
+                    suggest_list = suggest_list+" "+rec
     #
     # Remove version information
     #
@@ -626,8 +640,8 @@ def do_install_suggest(packages, type, noauth=""):
     # Remove duplicates
     #
     suggest_list = suggest_list + " "
-    for i in string.split(suggest_list):
-        suggest_list = i + " " + re.sub(" "+i+" ", ' ', suggest_list)
+    for i in suggest_list.split():
+        suggest_list = i + " " + re.sub(" " + i + " ", ' ', suggest_list)
     #
     # For the list of supplied packages and the list of suggested packages
     # do an install
@@ -645,8 +659,8 @@ def do_install_suggest(packages, type, noauth=""):
     # recommends installed, rather than going just one level.
 
     if type == "Recommends":
-        command = "aptitude %s -r --show-deps --show-versions install " % noauth \
-            + perform.concat(packages) + suggest_list
+        command = "aptitude %s -r --show-deps --show-versions install " % \
+            noauth + perform.concat(packages) + suggest_list
     else:
         command = "apt-get %s --show-upgraded install " % noauth \
             + perform.concat(packages) + suggest_list
@@ -666,6 +680,7 @@ def do_listsections():
             sections.append(s)
     print "\n".join(sections)
 
+
 def do_listsection(pattern):
     avail = get_available()
     for section in avail:
@@ -703,13 +718,16 @@ def do_listnames(pattern, pipe=False):
     if len(pattern) == 0:
         command = "apt-cache pkgnames | sort -k 1b,1"
     else:
-        command = "apt-cache pkgnames | grep -- " + pattern[0] + " | sort -k 1b,1"
+        command = "apt-cache pkgnames | grep -- " + pattern[0] \
+                + " | sort -k 1b,1"
     # Start fix for Bug #292581 - pre-run command to check for no output
     results = perform.execute(command, root=needsudo, pipe=True).readlines()
-    if len(results) == 0: sys.exit(1)
+    if len(results) == 0:
+        sys.exit(1)
     # End fix for Bug #292581
     return perform.execute(command, root=needsudo, pipe=pipe)
 
+
 def do_listscripts(pkg):
     scripts = ["preinst", "postinst", "prerm", "postrm"]
     if re.match(".*\.deb$", pkg):
@@ -717,7 +735,7 @@ def do_listscripts(pkg):
         pkgScripts = perform.execute(command, pipe=True).readlines()
         for script in scripts:
             if "./" + script in "".join(pkgScripts):
-                nlen = (72 - len(script))/2
+                nlen = (72 - len(script)) / 2
                 print ">"*nlen, script, "<"*nlen
                 command = "ar p " + pkg + " control.tar.gz |" +\
                           "tar zxvf - -O ./" + script +\
@@ -749,11 +767,12 @@ def do_new():
     #
     # List each package and it's version
     #
-    new_pkgs = changes.get_new_available();
+    new_pkgs = changes.get_new_available()
     new_pkgs.sort()
-    for i in range(0,len(new_pkgs)):
-        print "%-24s %s" % (new_pkgs[i], changes.get_available_version(new_pkgs[i]))
-                   
+    for i in range(0, len(new_pkgs)):
+        print "%-24s %s" % (new_pkgs[i],
+            changes.get_available_version(new_pkgs[i]))
+
 #------------------------------------------------------------------------
 #
 # NEWS
@@ -765,7 +784,7 @@ def map_sources(packages):
     Note that the source could include a version number.
     Only replace with source if package exists (Bug#295455).
 """
-    tagfile = apt_pkg.TagFile(open("/var/lib/dpkg/available","r"))
+    tagfile = apt_pkg.TagFile(open("/var/lib/dpkg/available", "r"))
     sources = []
     for section in tagfile:
         # May want to look to terminate as soon as all packages
@@ -779,6 +798,7 @@ def map_sources(packages):
                 sources += [[section.get("Package"), section.get("Package")]]
     return sources
 
+
 def do_news(packages):
     """List latest news for each package.
 
@@ -787,7 +807,6 @@ def do_news(packages):
 
     Returns: News items
     """
-    orig = packages
     ping_host("packages.debian.org")
     results = tempfile.mktemp()
     packages = map_sources(packages)
@@ -812,7 +831,8 @@ def do_news(packages):
         #
         command += "| awk 'NR==1{print;next} /^[^ ]/{exit}{print;next}' "
         perform.execute(command)
-        if os.path.exists(results): os.remove(results)
+        if os.path.exists(results):
+            os.remove(results)
 
 #------------------------------------------------------------------------
 #
@@ -821,52 +841,6 @@ def do_news(packages):
 # Updated 2004-10-19 07:00:08 graham Change host name
 #
 #------------------------------------------------------------------------
-
-# 2006-05-24 NO LONGER USED - COMMENT OUT FOR NOW THEN REMOVE ON NEXT
-# CLEANUP, JUST IN CASE...
-
-# def pool_version(pkg, orig):
-#     #
-#     # Check first if package is available, if not then
-#     # get version from original. Fixes Bug#295455
-#     #
-#     revert = False
-#     changes.load_dictionaries()
-#     available = changes.get_available_list()
-#     if pkg not in available:
-#         package = orig
-#         revert = True
-#     else:
-#         package = pkg
-#     #
-#     # Get the version
-#     #
-#     command = "apt-cache show " + package
-#     packages_pipe = perform.execute(command, noquiet=True, pipe=True)
-#     Parse = apt_pkg.TagFile(packages_pipe)
-#     version = '0'
-#     filename = ''
-#     while Parse.Step():
-#         v = Parse.Section.get("Version")
-#         if perform.execute("dpkg --compare-versions %s gt %s" % (v, version))\
-#                == 0:
-#             version = v
-#             filename = Parse.Section.get("Filename")
-#             #
-#             # If we reverted to the original package, be sure to get the
-#             # changelog from the source package. Fixes Bug#295455
-#             #
-#             if revert:
-#                 filename = filename.replace(orig, pkg)
-#             #
-#             # Special case of local installed packages.
-#             # Take a guess... Example is my own locally installed wajig.
-#             # 
-#             if filename[0:2] == "./":
-#                 filename = "pool/main/" + filename[2] +\
-#                            filename.split("_")[0][1:] + "/" + filename[2:]
-#     return (filename, version)
-
 def do_changelog(packages):
     """List latest changelog for each package.
 
@@ -875,16 +849,14 @@ def do_changelog(packages):
 
     Returns: Changelogs
     """
-    orig = packages
     ping_host("packages.debian.org")
-    results = tempfile.mktemp()
     packages = map_sources(packages)
     if not packages:
         # list the original package name (maybe it is a source package)
         # packages = map(lambda(x): [x,x], orig)
         print "No package of that name found - perhaps it's a source package."
     for pk in packages:
-        
+
         # map_sources was changed (gjw 17 Feb 2005) to return pairs
         # (source package name, original package name) so that we can
         # track the original package name in case the source package
@@ -893,7 +865,6 @@ def do_changelog(packages):
         # we don't any longer really need this.
 
         p = pk[0]
-        o = pk[1]
 
         # Print a header.
 
@@ -907,11 +878,9 @@ def do_changelog(packages):
 
         pkg = p.split()
         if len(pkg) > 1:
-            ver = pkg[1][1:-1] # Remove the round brackets
             pkg = pkg[0]
         else:
             pkg = pkg[0]
-            ver = "`egrep '^%s ' %s | cut -d' ' -f2`" % (pkg, available_file)
 
         # Find pool file name and get latest version number.
         # Previously I relied on changelogs.debian.net, but it seems
@@ -933,7 +902,7 @@ def do_changelog(packages):
 
         # Generate the command to retireve the changelog.
 
-        command  = "wget --timeout=60 --output-document=-"
+        command = "wget --timeout=60 --output-document=-"
         # (gjw 30 Dec 2004) command += " http://changelogs.debian.net/"
         command += " http://packages.debian.org/"
         #command += "changelogs/" + p[0] + "/"
@@ -959,14 +928,14 @@ def do_newupgrades(install=False):
     #
     # Load the dictionaries from file then list each one and it's version
     #
-    new_upgrades = changes.get_new_upgrades();
+    new_upgrades = changes.get_new_upgrades()
     if len(new_upgrades) == 0:
         print "No new upgrades"
     else:
         print "%-24s %-24s %s" % ("Package", "Available", "Installed")
-        print "="*24 + "-" + "="*24 + "-" + "="*24 
+        print "="*24 + "-" + "="*24 + "-" + "="*24
         new_upgrades.sort()
-        for i in range(0,len(new_upgrades)):
+        for i in range(0, len(new_upgrades)):
             print "%-24s %-24s %-24s" % (new_upgrades[i], \
                             changes.get_available_version(new_upgrades[i]), \
                             changes.get_installed_version(new_upgrades[i]))
@@ -984,13 +953,12 @@ def do_removedepend(pkg, purge=False):
     #
     dependencies = changes.get_dependencies(pkg)
     #
-    # For each dependency, find dependees that are installed.
+    # For each dependency, find dependents that are installed.
     # If only one is this pkg, then add it to the removal list.
     #
     if dependencies:
         for p in dependencies:
             # Check if the supplied pkg is the only dependee
-            dp = changes.get_dependees(p)
             if changes.get_dependees(p) == [pkg]:
                 toremove += " " + p
     #
@@ -1002,7 +970,6 @@ def do_removedepend(pkg, purge=False):
     else:
         perform.execute("apt-get remove " + toremove, root=1)
 
-
 ########################################################################
 # SIZE
 #
@@ -1012,7 +979,7 @@ def do_size(packages, size):
     # Work with the list of installed packages
     # (I think status has more than installed?)
     #
-    status = apt_pkg.TagFile(open("/var/lib/dpkg/status","r"));
+    status = apt_pkg.TagFile(open("/var/lib/dpkg/status", "r"));
     #
     # Initialise the sizes dictionary.
     #
@@ -1027,7 +994,7 @@ def do_size(packages, size):
             package_size   = section.get("Installed-Size")
             package_status = re.split(" ", section.get("Status"))[2]
             if package_size and int(package_size) > size:
-                if not size_list.has_key(package_name):
+                if package_name not in size_list:
                     size_list[package_name] = package_size
                     status_list[package_name] = package_status
     #
@@ -1097,7 +1064,7 @@ def do_status(packages, snapshot=False):
     # See Bug#288852 and Bug#119899.
     #
     perform.execute(changes.gen_installed_command_str() + " > " + ifile,
-                    noquiet=1, langC=True)
+                    noquiet=True, langC=True)
     #
     # Build the command to list the status of installed packages.
     #
@@ -1109,7 +1076,7 @@ def do_status(packages, snapshot=False):
     if len(packages) > 0:
         # Use grep, not egrep, otherwise g++ gets lost, for example!
         command = command + "grep '^\($"
-        for i in packages: 
+        for i in packages:
             command = command + " \|" + i
         command = command + " \)' |"
 
@@ -1126,7 +1093,7 @@ def do_status(packages, snapshot=False):
     # Check whether the package is not in the installed list, and if not
     # list its status appropriately.
     #
-    for i in packages: 
+    for i in packages:
         if os.system("egrep '^" + i + " ' " + ifile + " >/dev/null"):
             #
             # Package is not installed.
@@ -1142,7 +1109,8 @@ def do_status(packages, snapshot=False):
     #
     # Tidy up - remove the "installed file"
     #
-    if os.path.exists(ifile): os.remove(ifile)
+    if os.path.exists(ifile):
+        os.remove(ifile)
 
 #------------------------------------------------------------------------
 #
@@ -1159,23 +1127,23 @@ def do_toupgrade():
     # A simple way of doing this is to just list packages in the installed
     # list and the available list which have different versions.
     # However this does not capture the situation where the available
-    # package version predates the installed package version (e.g, 
+    # package version predates the installed package version (e.g,
     # you've installed a more recent version than in the distribution).
     # So now also add in a call to "dpkg --compare-versions" which slows
     # things down quite a bit!
     #
     print "%-24s %-24s %s" % ("Package", "Available", "Installed")
-    print "="*24 + "-" + "="*24 + "-" + "="*24 
+    print "="*24 + "-" + "="*24 + "-" + "="*24
     #
     # List each upgraded pacakge and it's version.
     #
-    to_upgrade = changes.get_to_upgrade();
+    to_upgrade = changes.get_to_upgrade()
     to_upgrade.sort()
-    for i in range(0,len(to_upgrade)):
+    for i in range(0, len(to_upgrade)):
         print "%-24s %-24s %-24s" % (to_upgrade[i], \
                             changes.get_available_version(to_upgrade[i]), \
                             changes.get_installed_version(to_upgrade[i]))
-    
+
 #------------------------------------------------------------------------
 #
 # edd 03 Sep 2003  unhold patch based on hold semantics
@@ -1184,10 +1152,10 @@ def do_toupgrade():
 #------------------------------------------------------------------------
 def do_unhold(packages):
     """Remove packages from hold (they will again be upgraded).
-    
+
     Arguments:
     packages   List of packages.
-    
+
     Returns:"""
 
     for p in packages:
@@ -1197,13 +1165,13 @@ def do_unhold(packages):
         perform.execute(command, root=1)
     print "The following packages are still on hold:"
     perform.execute("dpkg --get-selections | egrep 'hold$' | cut -f1")
-        
+
 #------------------------------------------------------------------------
 #
 # UPDATE
 #
 #------------------------------------------------------------------------
-def do_update(query=0, quiet=0):
+def do_update(query=0, quiet=False):
     """Perform.Execute an update of the available packages
 
     Arguments:
@@ -1213,19 +1181,20 @@ def do_update(query=0, quiet=0):
     Return status of the command"""
 
     if verbose > 0:
-        print "The Packages files listing the available packages is being updated."
+        print "The Packages files listing the available packages is being \
+               updated."
     if query > 0:
-        versionfile=open("/etc/debian_version");
-        debian_version = string.split(versionfile.read())[0];
+        versionfile = open("/etc/debian_version")
+        debian_version = versionfile.read().split()[0]
         if debian_version == "testing/unstable":
             print """
 You appear to be running the `unstable' or `testing' distribution of
-Debian. It is very likely that your Packages files are out of date. 
+Debian. It is very likely that your Packages files are out of date.
 Doing an UPDATE is recommended.
 """
         else:
             print """
-You appear to be running the `stable' distribution of Debian. It is not 
+You appear to be running the `stable' distribution of Debian. It is not
 likely that your Packages files are out of date. Doing an UPDATE is optional
 """
         doit = raw_input("Update? [Y/n] ")
@@ -1272,7 +1241,7 @@ likely that your Packages files are out of date. Doing an UPDATE is optional
         print "       It may need updating to use apt."
         print "       Or perhaps you purposely interrupted me."
 
-        exit(1);
+        exit(1)
 
 #------------------------------------------------------------------------
 #
@@ -1304,7 +1273,8 @@ def do_whatis0(packages):
                 "perl -p -e 's|<[^>]*>||g;s|^    ||g;" +\
                 "s|^&nbsp; |    |;s|&nbsp;||g;s|&quot;|\"|g;'"
             perform.execute(command)
-            if os.path.exists(results): os.remove(results)
+            if os.path.exists(results):
+                os.remove(results)
     else:
         print "Perhaps the server is temporarily down."
 
@@ -1357,7 +1327,7 @@ def do_whichpkg(filename):
     print "AVAILABLE"
     results = tempfile.mktemp()
     filename = filename.replace('+', '%2B')
-    
+
     # 100117 Bug#565666 Update to newer search syntax. TODO We should
     # really also determine the version and arch and pop the correct
     # ones in, rather than hard coding unstable and amd64.
@@ -1389,7 +1359,7 @@ def do_whichpkg(filename):
         # with the new HTML format, so maybe I don't need
         # to fix this one up. Just do a cat so that if we do
         # then someone is bound to notice!!!!
-        command = "cat " + results #+ " | " #+\
+        command = "cat " + results   # + " | " # +\
                   # HTML FORMAT CHANGED Oct 2007
                   # "egrep -v " +\
                   # "'^ *<|^$|^Packages search page|^package |//W3C//' | " +\
@@ -1435,7 +1405,8 @@ def do_whichpkg(filename):
         perform.execute(command)
     print "-"*77
 
-    if os.path.exists(results): os.remove(results)
+    if os.path.exists(results):
+        os.remove(results)
 
 #------------------------------------------------------------------------
 #
@@ -1478,14 +1449,14 @@ def do_findpkg(pkg):
               "print}'"
     perform.execute(command)
 
-    if os.path.exists(results): os.remove(results)
+    if os.path.exists(results):
+        os.remove(results)
 
 #------------------------------------------------------------------------
 #
 # RECDOWNLOAD
 #
 #------------------------------------------------------------------------
-
 def do_recdownload(packages):
     #FIXME: This has problems with virtual packages, FIX THEM!!!
 
@@ -1499,21 +1470,22 @@ def do_recdownload(packages):
         Author: Juanjo Alvarez <juanjux@yahoo.es>"""
 
     def get_deps(package):
-        tagfile = apt_pkg.TagFile(open("/var/lib/dpkg/available","r"))
+        tagfile = apt_pkg.TagFile(open("/var/lib/dpkg/available", "r"))
         deplist = []
         for section in tagfile:
-            if section.get("Package")==package:
-                deplist = apt_pkg.parse_depends(section.get("Depends",""))
+            if section.get("Package") == package:
+                deplist = apt_pkg.parse_depends(section.get("Depends", ""))
                 break
         realdeplist = []
         if deplist != []:
-            for i in deplist: realdeplist.append( (i[0][0],i[0][1]) )
+            for i in deplist:
+                realdeplist.append((i[0][0], i[0][1]))
         return realdeplist
 
     def get_deps_recursively(package, packageslist):
-        if not package in packageslist: packageslist.append(package)
-
-        for packageName,versionInfo in get_deps(package):
+        if not package in packageslist:
+            packageslist.append(package)
+        for packageName, versionInfo in get_deps(package):
             if packageName not in packageslist:
                 packageslist.append(packageName)
                 get_deps_recursively(packageName, packageslist)
@@ -1524,27 +1496,30 @@ def do_recdownload(packages):
     for p in packages[:]:
         # Ignore packages with a "-" at the end so the user can workaround some
         # dependencies problems (usually in unstable)
-        if p[len(p)-1:] == "-":
+        if p[len(p) - 1:] == "-":
             dontDownloadList.append(p[:-1])
             packages.remove(p)
             continue
 
     print "Calculating all dependencies..."
     for i in packages:
-        tmp = get_deps_recursively(i,[])
+        tmp = get_deps_recursively(i, [])
         for i in tmp:
             # We don't want dupplicated package names
             # and we don't want package in the dontDownloadList
-            if i in dontDownloadList: continue
-            if i not in packageNames: packageNames.append(i)
+            if i in dontDownloadList:
+                continue
+            if i not in packageNames:
+                packageNames.append(i)
     print "Packages to download to /var/cache/apt/archives:"
     for i in packageNames:
-        # We do this because apt-get install dont list the packages to reinstall
-        # if they don't need to be upgraded
+        # We do this because apt-get install dont list the packages to
+        # reinstall if they don't need to be upgraded
         print i,
     print "\n"
 
-    command = "apt-get --download-only --reinstall -u install " + perform.concat(packageNames)
+    command = "apt-get --download-only --reinstall -u install " \
+    + perform.concat(packageNames)
     perform.execute(command, root=1)
 
 
@@ -1556,7 +1531,7 @@ def versions(packages):
     for p in packages:
         command += "apt-show-versions " + p + "; "
     perform.execute(command)
-    
+
 
 def main():
     do_size([], 100)
