@@ -22,9 +22,7 @@
 
 import const
 
-#
-# VERSION
-#
+
 def version():
     print "JIG " + const.version +\
           """ - Command-line system admin for Debian GNU/Linux
@@ -40,9 +38,7 @@ On Debian systems, it may be found in /usr/share/common-licenses/GPL.
 Fuller documentation can be found at http://wajig.togaware.com/.
 """
 
-#
-# USAGE
-#
+
 def usage():
     print """Usage:
         wajig [options] [command] [packages|files] ...
@@ -58,6 +54,7 @@ def usage():
         Gnome-jig (gjig) provides a Gnome interface to JIG.
 
         Options include:
+        -b|--backup     Backup packages before they are upgraded.
         -d|--debug      Catch exceptions thrown by the program.
         -h|--help       Print this documentation and exit.
         -n|--noauth     Allow packages from unathenticated archives.
@@ -67,9 +64,7 @@ def usage():
         -y|--yes        Assume yes for any questions asked.
 """
 
-#
-# HELP
-#
+
 def help(verbose):
 
 #
@@ -94,7 +89,7 @@ def help(verbose):
  whatis         For each package named obtain a one line description
  whichpkg       Find the package that supplies the given command or file
 
-Run LIST-COMMANDS for a complete list of commands.
+Run 'wajig -v commands' for a complete list of commands.
 
 """
 
@@ -102,9 +97,10 @@ Run LIST-COMMANDS for a complete list of commands.
 # ALL COMMANDS AND OPTIONS
 #
     elif verbose == 1:
-      print """All JIG commands:
+        print """All JIG commands:
 
  addcdrom       Add a CD-ROM to the list of available sources of packages
+ addrepo        Add a Launchpad PPA (Personal Package Archive) repository
  auto-alts      Mark the alternative to be auto set (using set priorities)
  auto-clean     Remove superseded .deb files from the download cache
  auto-download  Do an update followed by a download of all updated packages
@@ -116,7 +112,6 @@ Run LIST-COMMANDS for a complete list of commands.
  build-depend   Retrieve packages required to build listed packages
  changelog      Retrieve latest changelog for the package
  clean          Remove all deb files from the download cache
- commands       List all the JIG commands and one line descriptions for each
  contents       List the contents of a package file
  daily-upgrade  Perform an update then a dist-upgrade
  dependents     List of packages which depend/recommend/suggest the package
@@ -127,11 +122,9 @@ Run LIST-COMMANDS for a complete list of commands.
  dist-upgrade   Upgrade to new distribution (installed and new rqd packages)
  docs           Equivalent to help with -verbose=2
  download       Download package files ready for an install
- editsources    Edit the list of archives for Debian packages
+ download-file  Download packages listed in file ready for an install
+ editsources    Edit list of archives which locates Debian package sources
  extract        Extract the files from a package file to a directory
- file-download  Download packages listed in file ready for an install
- file-install   Install packages listed in a file
- file-remove    Remove packages listed in a file
  find-file      Search for a file within installed packages
  find-pkg       Search for an unofficial Debian package at apt-get.org
  fix-configure  Perform dpkg --configure -a (to fix interrupted configure)
@@ -143,10 +136,11 @@ Run LIST-COMMANDS for a complete list of commands.
  init           Initialise or reset the JIG archive files
  info           List the information contained in a package file
  install        Install (or upgrade) one or more packages or .deb files
+ install-file   Install those packages that are listed in a file
  installr       Install package and associated recommended packages
  installrs      Install package and recommended and suggested packages
  installs       Install package and associated suggested packages
- install/dist   Install packages from specified distribution (must be in sources.list)
+ install/dist   Install packages from specified dist (must be in sources.list)
  integrity      Check the integrity of installed packages (through checksums)
  large          List size of all large (>10MB) installed packages
  last-update    Identify when an update was last performed
@@ -169,7 +163,6 @@ Run LIST-COMMANDS for a complete list of commands.
  list-wide      Same as list but avoids truncating package names
  local-dist-upgrade Dist-upgrade using packages already downloaded
  local-upgrade  Upgrade using packages already downloaded, but not any others
- locate	        Search for a file within installed packages
  madison        Runs the madison command of apt-cache.
  move           Move packages in the download cache to a local Debian mirror
  new            List packages that became available since last update
@@ -177,7 +170,6 @@ Run LIST-COMMANDS for a complete list of commands.
  new-upgrades   List packages newly available for upgrading
  non-free       List installed packages that do not meet the DFSG
  orphans        List libraries not required by any installed package
- package        Generate a .deb file for an installed package
  policy         From preferences file show priorities/policy (available)
  purge          Remove one or more packages and configuration files
  purge-depend   Purge package and those it depend on and not required by others
@@ -185,51 +177,45 @@ Run LIST-COMMANDS for a complete list of commands.
  purge-removed  Purge all packages marked as deinstall
  readme         Display the package's README file from /usr/share/doc
  recursive      Download package and any packages it depends on
- recommended    Install package and associated recommended packages
  reconfigure    Reconfigure the named installed packages or run gkdebconf
  reinstall      Reinstall each of the named packages
  reload         Reload daemon configs, e.g., gdm, apache (see list-daemons)
  remove         Remove one or more packages (see also purge)
- remove-depend  Remove package and its dependees not required by others
+ remove-depend  Remove package and its dependents not required by others
+ remove-file    Remove those packages that are listed in a file
  remove-orphans Remove orphaned libraries (not required by installed packages)
  repackage      Generate a .deb file for an installed package
  reset          Initialise or reset the JIG archive files
  restart        Stop then start a daemon, e.g., gdm, apache (see list-daemons)
  rpm2deb        Convert a RedHat .rpm file to a Debian .deb file
  rpminstall     Install a RedHat .rpm package
- rpmtodeb       Convert a RedHat .rpm file to a Debian .deb file
  search         Search for packages containing listed words
  search-apt     Find local Debian archives suitable for sources.list
- setup          Configure the sources.list file which locates Debian archives
- show           Provide a detailed description of package [same as detail]
+ setup          Alias for editsources
  showdistupgrade Trace the steps that a dist-upgrade would perform
  showinstall    Trace the steps that an install would perform
  showremove     Trace the steps that a remove would perform
  showupgrade    Trace the steps that an upgrade would perform
- size           Print out the size (in K) of all, or listed, installed packages
  sizes          Print out the size (in K) of all, or listed, installed packages
  snapshot       Generates list of package=version for all installed packages
  source         Retrieve and unpack sources for the named packages
  start          Start a daemon, e.g., gdm, apache (see list-daemons)
  status         Show the version and available version of packages
- status-match   Show the version and available version of matching packages
  status-search  Show the version and available version of matching packages
  stop           Stop a daemon, e.g., gdm, apache (see list-daemons)
- suggested      Install package and associated suggested packages
- tasksel        Run the Gnome task selector to install groups of packages
+ tasksel        Run the task selector to install groups of packages
  toupgrade      List packages with newer versions available for upgrading
  unhold         Remove listed packages from hold so they are again upgraded
- unofficial     Search for an unofficial Debian package at apt-get.org
  update         Update the list of downloadable packages
  update-alts    Update default alternative for things like x-window-manager
  update-pci-ids Updates the local list of PCI ids from the internet master list
  update-usb-ids Updates the local list of USB ids from the internet master list
  upgrade        Upgrade all of the installed packages or just those listed
- verify		Check the md5sums of a package.
- version	Show the current version of wajig.
+ verify         Check the md5sums of a package.
+ version        Show the current version of wajig.
  versions       List version and distribution of (all) packages.
  whatis         A synonym for describe
- whichpkg       Find the package that supplies the given command or file 
+ whichpkg       Find the package that supplies the given command or file
 
 Command line options:
 
@@ -246,9 +232,10 @@ Fuller documentation can be found at http://www.togaware.com/wajig.
 
 #
 # FULL DOCUMENTATION
+# TODO: no entry for 'addrepo'
 #
     else:
-      print """Welcome to JIG, bringing the pieces of system
+        print """Welcome to JIG, bringing the pieces of system
 administration together - a tool for Debian GNU/Linux.
 
 JIG is Copyright (c) Graham.Williams@togaware.com
@@ -325,7 +312,7 @@ If you've tried to remember all the different commands to get
 different information about different aspects of Debian package
 management and then used other commands to install and remove packages
 then you'll know that it can become a little too much.
- 
+
 Swapping between dselect, deity, deity-gtk, aptitude, apt-get, dpkg,
 gnome-apt, apt-cache, and so on is interesting but cumbersome.  Plus
 personally I find dselect, deity, and aptitude confusing and even
@@ -358,8 +345,8 @@ Debian. The command line interface is apt-get but it is also used
 within wajig dselect, deity, and aptitude. See
 http://newbieDoc.sourceForge.net/system/apt-get-intro.html for a great
 introduction to apt-get. Also see
-  
-  /usr/share/doc/apt/offline.html/index.html 
+
+  /usr/share/doc/apt/offline.html/index.html
 
 on your local Debian machine for using apt off line.
 
@@ -375,7 +362,7 @@ for sudo or regularly supplying passwords). Using sudo requires a
 little setting up as described below.
 
 Try the help command for a list of common commands provided by
-wajig: 
+wajig:
 
   $ wajig help
 
@@ -405,12 +392,12 @@ All wajig commands:
 
 Command line options:
 
- -h|--help      Print usage message. 
+ -h|--help      Print usage message.
  -n|--noauth    Allow packages from unathenticated archives.
- -q|--quiet     Do system commands everything quietly. 
- -s|--simulate  Trace but don't execute the sequence of underlying commands. 
- -t|--teaching  Trace the sequence of commands performed. 
- -v|--verbose=n Increase (or set) the level of verbosity (to n). 
+ -q|--quiet     Do system commands everything quietly.
+ -s|--simulate  Trace but don't execute the sequence of underlying commands.
+ -t|--teaching  Trace the sequence of commands performed.
+ -v|--verbose=n Increase (or set) the level of verbosity (to n).
  -y|--yes       Assume yes for any questions asked.
 
 Wajig expects a command and will call upon other Debian tools to
@@ -435,7 +422,7 @@ message.
 Installing sudo is straight forward. As root run the command visudo to
 edit the configration file.  Add the lines:
 
-  Cmnd_Alias  APT = /usr/bin/apt-get, /usr/bin/apt-cache, /usr/bin/dpkg, \\ 
+  Cmnd_Alias  APT = /usr/bin/apt-get, /usr/bin/apt-cache, /usr/bin/dpkg, \\
                     /usr/sbin/dpkg-reconfigure, /usr/bin/dpkg-repack, \\
                     /etc/init.d/*, /usr/sbin/update-alternatives, \\
                     /usr/lib/apt-move/fetch, /usr/bin/dselect, \\
@@ -457,7 +444,7 @@ packages with what is currently available from the Debian archives for
 downloading.  If you are staying with the stable release you generally
 only need to update the list of available packages once.  The
 following command is used to update the information about what is
-available for downloading: 
+available for downloading:
 
   $ wajig update                (dselect update)
 
@@ -466,7 +453,7 @@ wajig calls upon to perform the operation.)
 
 This uses entries in the file /etc/apt/sources.list to know where to
 get the list of available packages from and which release of Debian
-you wish to follow.  You can edit this file with: 
+you wish to follow.  You can edit this file with:
 
   $ wajig editsources           (apt-setup)
 
@@ -481,7 +468,7 @@ section.
 If you have a Debian CD-ROM or DVD-ROM then you can tell apt what is
 available on it using:
 
-  $ wajig add-cd-rom  
+  $ wajig add-cd-rom
 
 
 
@@ -499,7 +486,7 @@ which you can then review and add to the system sources.list, if you
 wish, with
 
   $ wajig edit-sources
-  
+
 
 FINDING PACKAGES
 
@@ -629,7 +616,7 @@ you can install it with:
 The .deb file will be searched for in both the current directory and
 in the apt archive at /var/cache/apt/archive/.
 
-You can list multiple .deb files to install. 
+You can list multiple .deb files to install.
 
 If the .deb package file you wish to install is available on the
 internet you can give its address and wajig will download then install
@@ -653,6 +640,15 @@ You can upgrade all installed packages with:
 
   $ wajig upgrade                       (apt-get -u upgrade)
 
+You can also backup packages just before upgrading them with:
+
+  $ wajig --backup upgrade              (apt-get -u upgrade)
+
+This will run "dpkg-repack" inside a dated directory in "~/.wajig/backups"
+and place the packages in there. You have an option to specify another
+directory: "wajig -b upgrade here" will create "here/2010-08-20_22:53:42"
+in the current directory, for example, and place the packages in there.
+
 And you can upgrade all installed packages, remove those packages that
 need to be removed (for various reasons, including issues to do with
 dependencies) and install all newly required packages in the
@@ -681,7 +677,7 @@ A neat trick with wajig is the ability to upgrade a collection of
 packages all with the same version number to another common version
 number:
 
-  $ wajig status | grep 3.2.3-2 | grep 3.3.0-1 | cut -f1 > list 
+  $ wajig status | grep 3.2.3-2 | grep 3.3.0-1 | cut -f1 > list
   $ wajig install-file list
 
 
@@ -861,7 +857,7 @@ Be sure to edit the list to remove, for example, gcc! Then a:
 
   $ sudo apt-build world
 
-will recompile and optimise all packages. 
+will recompile and optimise all packages.
 
 PINNING DISTRIBUTIONS
 
@@ -949,7 +945,7 @@ include:
   gdm    The Gnome Windows Display Manager (for logging on)
   ssh    The Secure Shell daemon
 
-Generally, daemons are started at system boot time automatically. 
+Generally, daemons are started at system boot time automatically.
 
 ALTERNATIVE APPLICATIONS
 
@@ -1012,7 +1008,7 @@ To remove files immediately after they have been installed edit
 /etc/apt/apt.conf:
 
   // Things that effect the APT dselect method
-  DSelect 
+  DSelect
   {
     Clean "auto";   // always|auto|prompt|never
   ;
@@ -1030,7 +1026,7 @@ list run:
 
   deb http://snapshot.debian.net/archive pool sed
 
-Then you can do, for example: 
+Then you can do, for example:
 
   $ wajig available sed
   $ wajig install sed=4.1.2-1
